"use client";

import { createContext, useContext, useState, useEffect } from "react";

export const ThemeContext = createContext();
export const useAppContext = () => useContext(ThemeContext);

export default function ThemeProvider({ children, ...props }) {
  // State for theme
  const [theme, setTheme] = useState("light");

  useEffect(() => {
    handleThemeChange();
  }, [theme]);

  // Function to handle theme changes
  const handleThemeChange = () => {
    const storedTheme = localStorage.getItem("theme");

    if (!storedTheme) {
      // Set default theme to light if not stored
      setDefaultTheme();
    } else {
      // Set theme from storage
      setThemeFromStorage(storedTheme);
    }
  };

  // Function to set default theme to light
  const setDefaultTheme = () => {
    const defaultTheme = "light";
    localStorage.setItem("theme", defaultTheme);
    setThemeAndApplyClass(defaultTheme);
  };

  // Function to set theme from storage
  const setThemeFromStorage = (storedTheme) => {
    setThemeAndApplyClass(storedTheme);
  };

  // Function to set theme and apply class to document element
  const setThemeAndApplyClass = (newTheme) => {
    localStorage.setItem("theme", newTheme);
    setTheme(newTheme);
    document.documentElement.setAttribute("class", newTheme);
  };

  const contextValue = {
    theme,
    setTheme,
    ...props,
  };

  return (
    <ThemeContext.Provider value={contextValue}>
      {children}
    </ThemeContext.Provider>
  );
}
